@@ -76,9 +76,12 @@ sjt.grpmean <- function(varCount,
   # --------------------------------------
   # set value and row labels
   # --------------------------------------
-  if (is.null(rowLabels)) rowLabels <- sjmisc:::autoSetValueLabels(varGrp)
-  varGrpLabel <- sjmisc:::autoSetVariableLabels(varGrp)
-  varCountLabel <- sjmisc:::autoSetVariableLabels(varCount)
+  if (is.null(rowLabels)) rowLabels <- sjmisc::get_labels(varGrp,
+                                                          attr.only = F,
+                                                          include.values = NULL,
+                                                          include.non.labelled = T)
+  varGrpLabel <- sjmisc::get_label(varGrp, def.value = get_var_name(deparse(substitute(varGrp))))
+  varCountLabel <- sjmisc::get_label(varCount, def.value = get_var_name(deparse(substitute(varCount))))
   # --------------------------------------
   # handle NULL parameter
   # --------------------------------------
@@ -204,7 +207,7 @@ sjt.grpmean <- function(varCount,
   # check if html-content should be printed
   # -------------------------------------
   out.html.table(no.output, file, html$knitr, html$output.complete, useViewer)  
-  invisible(list(class = "sjtgrpmean",
+  invisible(list(class = c("sjTable", "sjtgrpmean"),
                  df = df, 
                  page.style = html$page.style,
                  page.content = html$page.content,
